<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he_IL">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>יומן שינויים</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>התאמות MX</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="508"/>
        <location filename="../tweak.ui" line="587"/>
        <location filename="../tweak.ui" line="643"/>
        <location filename="../tweak.ui" line="670"/>
        <location filename="../tweak.ui" line="862"/>
        <location filename="../tweak.ui" line="1253"/>
        <location filename="../tweak.ui" line="1382"/>
        <location filename="../tweak.ui" line="1429"/>
        <location filename="../tweak.ui" line="1679"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>החלה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1036"/>
        <location filename="../tweak.ui" line="1146"/>
        <location filename="../tweak.ui" line="1273"/>
        <source>Placement</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>גיבוי הגדרות הלוח הנוכחי</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>שחזור לוח ברירת המחדל</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>כרך</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>ערכת נושא</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>אפשרויות ערכת נושא</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>הסרת ערכת עיצוב של משתמש</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="295"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="298"/>
        <source>Dark Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="305"/>
        <location filename="../tweak.ui" line="1742"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>מנהל חלונות</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="319"/>
        <source>Legacy Styles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="332"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>סמלים</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="339"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="346"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>שמירת ההגדרות הנוכחיות כערכת עיצוב</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="356"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>גודל</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="366"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>ברירת מחדל</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="389"/>
        <location filename="../tweak.ui" line="441"/>
        <source>Compositor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="404"/>
        <source>VBlank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="412"/>
        <source>auto</source>
        <translation>אוטומטי</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="417"/>
        <source>glx</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="422"/>
        <source>xpresent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="427"/>
        <location filename="../tweak.ui" line="1010"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>כבוי</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="435"/>
        <source>Transparency and shadow options</source>
        <translation>אפשרויות שקיפות והצללה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="451"/>
        <source>Xfce Compositor Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="454"/>
        <source>Xfwm Settings</source>
        <translation>הגדרות Xfwm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="464"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>הפעלת כלי ההגדרות compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="467"/>
        <source>Picom settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="478"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>עריכת compton.conf ישירות בעורך טקסט</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="481"/>
        <source>Edit picom.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="528"/>
        <source>Display</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="534"/>
        <source>Display Tweaks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>אור אחורי חומרתי</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="563"/>
        <location filename="../tweak.ui" line="694"/>
        <source>TextLabel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="570"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="623"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>בחירת תצוגה לשפצורי xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="633"/>
        <source>Resolution</source>
        <translation>רזולוציה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="650"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="677"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>בהירות תוכנה (xrandr)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="701"/>
        <source>Saving is per display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="704"/>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="728"/>
        <source>Xfce</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="734"/>
        <source>Desktop</source>
        <translation>שולחן עבודה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Enable single-click on desktop</source>
        <translation>להפעיל לחיצה בודדת בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="747"/>
        <source>Enable Desktop Zoom </source>
        <translation>הפעלת תקריב שולחן עבודה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="754"/>
        <location filename="../tweak.ui" line="1343"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>הצגת חלונות מכל סביבות העבודה בלוח</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="761"/>
        <source>Do not shorten file names on the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="771"/>
        <source>Thunar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="777"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>הפעלת לחיצה בודדת במנהל הקבצים Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="784"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="791"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="798"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="808"/>
        <source>Show percentages in notifcations when available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="815"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="822"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="832"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>הפעלת תרדמת בתפריט היציאה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="839"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="873"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="879"/>
        <location filename="../tweak.ui" line="1353"/>
        <source>Reset Defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Reset DefaultDock</source>
        <translation>איפוס DefaultDock</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="892"/>
        <source>Reset Fluxbox Menu</source>
        <translation>איפוס תפריט Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="899"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>איפוס כל הגדרות mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="906"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="909"/>
        <source>Upgrade existing menu entries</source>
        <translation>שדרוג רשומות קיימות בתפריט</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="919"/>
        <source>Desktop Icons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="925"/>
        <source>Toggle desktop icons</source>
        <translation>הצגת/הסתרת הסמלים בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="933"/>
        <location filename="../tweak.ui" line="957"/>
        <source>On</source>
        <translation>מופעל</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="938"/>
        <location filename="../tweak.ui" line="962"/>
        <source>Off</source>
        <translation>כבוי</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="946"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="967"/>
        <source>On Hover</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="994"/>
        <source>Screensaver</source>
        <translation>שומר מסך</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1000"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1023"/>
        <source>Toolbar Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1029"/>
        <source>Height</source>
        <translation>גובה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1110"/>
        <location filename="../tweak.ui" line="1220"/>
        <source>Autohide</source>
        <translation>הסתרה אוטומטית</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1117"/>
        <source>Show Toolbar</source>
        <translation>הצגת סרגל כלים</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1124"/>
        <source>Width</source>
        <translation>רוחב</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1140"/>
        <source>Dock Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1227"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1261"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1267"/>
        <source>Affects 1st panel</source>
        <translation>משפיע על הלוח הראשון</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1284"/>
        <source>Bottom</source>
        <translation>תחתית</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1289"/>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1294"/>
        <source>Top</source>
        <translation>עליון</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1299"/>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1323"/>
        <source>Workspace</source>
        <translation>סביבת עבודה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1329"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1336"/>
        <source>Enable single-click</source>
        <translation>הפעלת לחיצה בודדת</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1359"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>שחזור לברירת המחדל של KDE/‏Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1393"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1399"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1402"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1412"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1419"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1450"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1456"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1463"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1470"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1477"/>
        <source>requires reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1480"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1487"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1497"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1504"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1528"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1535"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1538"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1571"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1578"/>
        <source>Use tearfree amdgpu option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1585"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1592"/>
        <source>Use tearfree radeon driver option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1599"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1606"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1629"/>
        <source>Password for administrative tasks:</source>
        <translation>סיסמה למשימות ניהוליות:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1636"/>
        <source>&amp;User</source>
        <translation>&amp;משתמש</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1643"/>
        <source>Root</source>
        <translation>שורש (root)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1693"/>
        <source>Xfce Settings</source>
        <translation>הגדרות Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1699"/>
        <source>Customize the panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1709"/>
        <source>Panel</source>
        <translation>לוח</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Configure window behavior and shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1762"/>
        <source>Customize the look of your desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1775"/>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1787"/>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1797"/>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1855"/>
        <source>Quit application</source>
        <translation>יציאה מהיישום</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1858"/>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1864"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>על אודות התאמות MX</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>גרסה:</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>זכויות היוצרים (c) שמורות ל־MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>רישיון של %1</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>עזרה עבור %1</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="289"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>נא להזין שם למחשב.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="293"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>התאמות MX</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>משם קובץ</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>שם הקובץ כבר קיים. נא לבחור שם אחר</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>הקובץ אינו ארכיון tar.xz תקני</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>הארכיון לא מכיל הגדרות לוח</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>בהירות תוכנה (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>אור אחורי חומרתי</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;יציאה</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>הסרת ערכת עיצוב של משתמש</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>קיבוץ חלונות:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>אף פעם</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>תמיד</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>פעולת לחיצה אמצעית:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>לסגור חלון</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>למזער חלון</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>תיבת דו־שיח</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>להציג צלליות מתחת לחלונות הקופצים</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>להציג צלליות מתחת לחלונות המעגן</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>להציג צלליות מתחת לחלונות רגילים</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>עיטורי חלונות</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>חלונות במהלך שינוי גודל</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>